==> nextcloud-30.0.5.tgz: nextcloud/apps/serverinfo/l10n/cs.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informace o procesoru nejsou k dispozici",
    "CPU Usage:" : "Využití procesoru:",
    "Load average: {percentage} % ({load}) last minute" : "Průměrné vytížení: {percentage} % ({load}) za uplynulou minutu",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) uplynulá minuta\n{last5MinutesPercentage} % ({last5Minutes}) uplynulých 5 minut\n{last15MinutesPercentage} % ({last15Minutes}) uplynulých 15 minut",
    "RAM Usage:" : "Využití operační paměti:",
    "SWAP Usage:" : "Využití odkládacího prostoru:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "Operační paměť: Celkem: {memTotalBytes}/Stávající využití: {memUsageBytes}",
    "RAM info not available" : "Informace o operační paměti nejsou k dispozici",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "Odkládací prostor (swap): Celkem: {swapTotalBytes}/Stávající využití: {swapUsageBytes}",
    "SWAP info not available" : "Informace o odkládacím prostoru (swap) nejsou k dispozici",
    "Copied!" : "Zkopírováno!",
    "Not supported!" : "Nepodporováno!",
    "Press ⌘-C to copy." : "Zkopírujete stisknutím ⌘C.",
    "Press Ctrl-C to copy." : "Zkopírujete stisknutím Ctrl+C.",
    "System" : "Systém",
    "Monitoring" : "Dohledování",
    "Monitoring app with useful server information" : "Dohledovací aplikace, poskytující užitečné informace o serveru",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Poskytuje užitečné informace o serveru, jako vytížení procesoru, využití operační paměti, obsazenost datového úložiště, počet uživatelů, atd.",
    "Operating System:" : "Operační systém:",
    "CPU:" : "Procesor:",
    "Unknown Processor" : "Neznámý procesor",
    "Memory:" : "Operační paměť:",
    "Server time:" : "Čas na serveru:",
    "Uptime:" : "Doba chodu od minulého zapnutí:",
    "Temperature" : "Teplota",
    "Load" : "Vytížení",
    "Memory" : "Operační paměť",
    "Disk" : "Úložiště",
    "Mount:" : "Připojeno pod:",
    "Filesystem:" : "Souborový systém:",
    "Size:" : "Velikost:",
    "Available:" : "K dispozici:",
    "Used:" : "Použito:",
    "Files:" : "Souborů:",
    "Storages:" : "Úložišť:",
    "Free Space:" : "Volné místo:",
    "Network" : "Síť",
    "Hostname:" : "Název stroje:",
    "Gateway:" : "Brána:",
    "Status:" : "Stav:",
    "Speed:" : "Rychlost:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC adresa:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktivní uživatelé",
    "Last hour" : "Uplynulá hodina",
    "%s%% of all users" : "%s%% ze všech uživatelů",
    "Last 24 Hours" : "Uplynulých 24 hodin",
    "Last 7 Days" : "Uplynulých 7 dnů",
    "Last 30 Days" : "Uplynulých 30 dnů",
    "Shares" : "Sdílení",
    "Users:" : "Uživatelé:",
    "Groups:" : "Skupiny:",
    "Links:" : "Odkazy:",
    "Emails:" : "E-maily:",
    "Federated sent:" : "Federovaně odesláno:",
    "Federated received:" : "Federovaně přijato:",
    "Talk conversations:" : "Konverzace v Talk:",
    "PHP" : "PHP",
    "Version:" : "Verze:",
    "Memory limit:" : "Limit paměti:",
    "Max execution time:" : "Nejdelší umožněný čas vykonávání:",
    "Upload max size:" : "Nejvyšší umožněná velikost nahrávaného souboru:",
    "OPcache Revalidate Frequency:" : "Četnost opětovného ověřování platnosti OPcache mezipaměti:",
    "Extensions:" : "Rozšíření:",
    "Unable to list extensions" : "Nepodařilo se vypsat rozšíření",
    "Show phpinfo" : "Zobrazit phpinfo",
    "Database" : "Databáze",
    "Type:" : "Typ:",
    "External monitoring tool" : "Externí nástroj pro dohledování",
    "Use this end point to connect an external monitoring tool:" : "Pro napojení na externí dohledovací nástroj použijte tento koncový bod:",
    "Copy" : "Zkopírovat",
    "Output in JSON" : "Výstup v JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Přeskočit sekci aplikací (včetně toho, že sekce aplikací odešle externí požadavek do katalogu aplikací)",
    "Skip server update" : "Přeskočit přechod na novější vydání serveru",
    "To use an access token, please generate one then set it using the following command:" : "Aby bylo možné použít přístupový token, vytvořte ho a pak nastavte pomocí následujícího příkazu:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Poté při dotazování výše uvedené URL předávejte se záhlavím „NC-Token“.",
    "Load average: {cpu} (last minute)" : "Průměrné vytížení: {cpu} (za uplynulou minutu)",
    "DNS:" : "DNS:",
    "Total users:" : "Celkem uživatelů:",
    "24 hours:" : "24 hodin:",
    "1 hour:" : "1 hodina:",
    "5 mins:" : "5 minut:"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-30.0.12.tgz: nextcloud/apps/serverinfo/l10n/cs.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informace o procesoru nejsou k dispozici",
    "CPU Usage:" : "Využití procesoru:",
    "Load average: {percentage} % ({load}) last minute" : "Průměrné vytížení: {percentage} % ({load}) za uplynulou minutu",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) uplynulá minuta\n{last5MinutesPercentage} % ({last5Minutes}) uplynulých 5 minut\n{last15MinutesPercentage} % ({last15Minutes}) uplynulých 15 minut",
    "RAM Usage:" : "Využití operační paměti:",
    "SWAP Usage:" : "Využití odkládacího prostoru:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "Operační paměť: Celkem: {memTotalBytes}/Stávající využití: {memUsageBytes}",
    "RAM info not available" : "Informace o operační paměti nejsou k dispozici",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "Odkládací prostor (swap): Celkem: {swapTotalBytes}/Stávající využití: {swapUsageBytes}",
    "SWAP info not available" : "Informace o odkládacím prostoru (swap) nejsou k dispozici",
    "Copied!" : "Zkopírováno!",
    "Not supported!" : "Nepodporováno!",
    "Press ⌘-C to copy." : "Zkopírujete stisknutím ⌘C.",
    "Press Ctrl-C to copy." : "Zkopírujete stisknutím Ctrl+C.",
    "System" : "Systém",
    "Monitoring" : "Dohledování",
    "Monitoring app with useful server information" : "Dohledovací aplikace, poskytující užitečné informace o serveru",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Poskytuje užitečné informace o serveru, jako vytížení procesoru, využití operační paměti, obsazenost datového úložiště, počet uživatelů, atd.",
    "Operating System:" : "Operační systém:",
    "CPU:" : "Procesor:",
    "Unknown Processor" : "Neznámý procesor",
    "Memory:" : "Operační paměť:",
    "Server time:" : "Čas na serveru:",
    "Uptime:" : "Doba chodu od minulého zapnutí:",
    "Temperature" : "Teplota",
    "Load" : "Vytížení",
    "Memory" : "Operační paměť",
    "Disk" : "Úložiště",
    "Mount:" : "Připojeno pod:",
    "Filesystem:" : "Souborový systém:",
    "Size:" : "Velikost:",
    "Available:" : "K dispozici:",
    "Used:" : "Použito:",
    "Files:" : "Souborů:",
    "Storages:" : "Úložišť:",
    "Free Space:" : "Volné místo:",
    "Network" : "Síť",
    "Hostname:" : "Název stroje:",
    "Gateway:" : "Brána:",
    "Status:" : "Stav:",
    "Speed:" : "Rychlost:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC adresa:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktivní uživatelé",
    "Last hour" : "Uplynulá hodina",
    "%s%% of all users" : "%s%% ze všech uživatelů",
    "Last 24 Hours" : "Uplynulých 24 hodin",
    "Last 7 Days" : "Uplynulých 7 dnů",
    "Last 30 Days" : "Uplynulých 30 dnů",
    "Shares" : "Sdílení",
    "Users:" : "Uživatelé:",
    "Groups:" : "Skupiny:",
    "Links:" : "Odkazy:",
    "Emails:" : "E-maily:",
    "Federated sent:" : "Federovaně odesláno:",
    "Federated received:" : "Federovaně přijato:",
    "Talk conversations:" : "Konverzace v Talk:",
    "PHP" : "PHP",
    "Version:" : "Verze:",
    "Memory limit:" : "Limit paměti:",
    "Max execution time:" : "Nejdelší umožněný čas vykonávání:",
    "Upload max size:" : "Nejvyšší umožněná velikost nahrávaného souboru:",
    "OPcache Revalidate Frequency:" : "Četnost opětovného ověřování platnosti OPcache mezipaměti:",
    "Extensions:" : "Rozšíření:",
    "Unable to list extensions" : "Nepodařilo se vypsat rozšíření",
    "Show phpinfo" : "Zobrazit phpinfo",
    "FPM worker pool" : "Fond procesů zpracovávajících FPM",
    "Pool name:" : "Název fondu:",
    "Pool type:" : "Typ fondu:",
    "Start time:" : "Čas zahájení:",
    "Accepted connections:" : "Přijatá připojení:",
    "Total processes:" : "Celkem procesů:",
    "Active processes:" : "Aktivních procesů:",
    "Idle processes:" : "Neaktivních procesů:",
    "Listen queue:" : "Fronta očekávání spojení:",
    "Slow requests:" : "Pomalé požadavky:",
    "Max listen queue:" : "Délka fronty délka fronty očekávání spojení nejvýše:",
    "Max active processes:" : "Nejvýše aktivních procesů:",
    "Max children reached:" : "Nejvyšší dosažený počet podřízených procesů:",
    "Database" : "Databáze",
    "Type:" : "Typ:",
    "External monitoring tool" : "Externí nástroj pro dohledování",
    "Use this end point to connect an external monitoring tool:" : "Pro napojení na externí dohledovací nástroj použijte tento koncový bod:",
    "Copy" : "Zkopírovat",
    "Output in JSON" : "Výstup v JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Přeskočit sekci aplikací (včetně toho, že sekce aplikací odešle externí požadavek do katalogu aplikací)",
    "Skip server update" : "Přeskočit přechod na novější vydání serveru",
    "To use an access token, please generate one then set it using the following command:" : "Aby bylo možné použít přístupový token, vytvořte ho a pak nastavte pomocí následujícího příkazu:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Poté při dotazování výše uvedené URL předávejte se záhlavím „NC-Token“."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
